@@ -2,17 +2,18 @@ context("readLAS")
 
 LASfile <- system.file("extdata", "Megaplot.laz", package="lidR")
 
-test_that("read las works", {
+test_that("readLAS works", {
   las = readLAS(LASfile)
   expect_is(las, "LAS")
 })
 
-test_that("read unexisting file fails", {
-  expect_error(readLAS("unexistingfile.las"))
+test_that("readLAS returns a error for non-existing file", {
+  expect_error(readLAS("unexistingfile.las"), regexp = "File does not exist")
 })
 
-test_that("read XYZ only works", {
+test_that("read only XYZ attributes works", {
   las = readLAS(LASfile, select = "xyz")
+  expect_equal(names(las@data), c("X", "Y", "Z"))
   expect_equal(ncol(las@data), 3)
 })
 
@@ -21,10 +22,3 @@ test_that("read multiple files works", {
   las2 = readLAS(rep(LASfile, 3))
   expect_equal(3*dim(las@data)[1], dim(las2@data)[1])
 })
-
-test_that("print las works", {
-  las  = readLAS(LASfile)
-  sink(tempfile())
-  expect_error(summary(las), NA)
-  sink(NULL)
-})
\ No newline at end of file
